@@ -37,7 +37,8 @@ class MeioPagamentoCadastro(CadastroBase):
         }
 
 
-PARCELAS = [(0, "Todas"), (1, 1), (2, 2), (3, 3), (4, 4), (5, 5), (6, 6), (7, 7), (8, 8), (9, 9), (10, 10), (11, 11), (12, 12)]
+PARCELAS = [(x, x) for x in range(1, 13)]
+PARCELAS.insert(0, (12, "Todas"))
 
 
 class Formulario(FormularioBase):
