@@ -52,7 +52,7 @@ class EnviarPedido(Enviar):
             paymentrequest_0_amt=self.formatador.formata_decimal(self.pedido.valor_total),
             paymentrequest_0_shippingamt=self.formatador.formata_decimal(self.valor_envio),
             paymentrequest_0_currencycode="BRL",
-            paymentrequest_0_itemamt=self.formatador.formata_decimal(self.pedido.valor_subtotal),
+            paymentrequest_0_itemamt=self.formatador.formata_decimal(self.valor_subtotal),
             paymentrequest_0_invnum=self.pedido.numero,
 
             paymentrequest_0_shiptoname=unicode(self.pedido.endereco_entrega.nome),
@@ -64,6 +64,7 @@ class EnviarPedido(Enviar):
             paymentrequest_0_shiptocountrycode="BR",
             paymentrequest_0_shiptophonenum=self.pedido.cliente.telefone_principal
         )
+        indice_final = 0
         for indice, item in enumerate(self.pedido.itens.all()):
             self.define_valor_de_atributo_de_item(express_checkout, "NAME", indice, unicode(item.nome[:127]))
             self.define_valor_de_atributo_de_item(express_checkout, "DESC", indice, "")
@@ -71,6 +72,12 @@ class EnviarPedido(Enviar):
             self.define_valor_de_atributo_de_item(express_checkout, "QTY", indice, self.formatador.formata_decimal(item.quantidade))
             self.define_valor_de_atributo_de_item(express_checkout, "NUMBER", indice, unicode(item.sku[:127]))
             self.define_valor_de_atributo_de_item(express_checkout, "ITEMURL", indice, item.produto.get_absolute_url() or "")
+            indice_final = indice
+        indice_final += 1
+        if self.valor_desconto:
+            self.define_valor_de_atributo_de_item(express_checkout, "NAME", indice_final, "Desconto")
+            self.define_valor_de_atributo_de_item(express_checkout, "AMT", indice_final, self.formatador.formata_decimal((self.valor_desconto * -1)))
+            self.define_valor_de_atributo_de_item(express_checkout, "QTY", indice_final, 1)
         return express_checkout.to_dict()
 
     def define_valor_de_atributo_de_item(self, express_checkout, atributo, indice, valor):
